"""It is a real time technical analysis library useful to perform
incremental feature engineering from financail time series datasets in
realtime.  If you are looking to perform technical analysis against
pre computed historical data sets you are better off using the more
complete https://pypi.org/project/ta/ project.  This project omits
"repainting" metrics and generally trades overall performance for
lower next value latency.

.. moduleauthor:: Adam DePrince (adamdeprince)

"""

